@@ -15,6 +15,10 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-__all__ = ["classifier"]
+__all__ = ["classifier", "regression", "recommender", "stat", "graph"]
 
-# from jubatus.classifier import Classifier
+from jubatus.classifier.client import classifier as Classifier
+from jubatus.regression.client import regression as Regression
+from jubatus.recommender.client import recommender as Recommender
+from jubatus.stat.client import stat as Stat
+from jubatus.graph.client import graph as Graph
