@@ -24,12 +24,12 @@ class classifier:
     retval = self.client.call('classify', name, data)
     return [[estimate_result.from_msgpack(elem_elem_retval) for elem_elem_retval in elem_retval] for elem_retval in retval]
 
-  def save (self, name, arg1):
-    retval = self.client.call('save', name, arg1)
+  def save (self, name, id):
+    retval = self.client.call('save', name, id)
     return retval
 
-  def load (self, name, arg1):
-    retval = self.client.call('load', name, arg1)
+  def load (self, name, id):
+    retval = self.client.call('load', name, id)
     return retval
 
   def get_status (self, name):
