@@ -16,12 +16,12 @@ class regression:
     retval = self.client.call('get_config', name)
     return config_data.from_msgpack(retval)
 
-  def train (self, arg0, arg1):
-    retval = self.client.call('train', arg0, arg1)
+  def train (self, name, train_data):
+    retval = self.client.call('train', name, train_data)
     return retval
 
-  def estimate (self, arg0, arg1):
-    retval = self.client.call('estimate', arg0, arg1)
+  def estimate (self, name, estimate_data):
+    retval = self.client.call('estimate', name, estimate_data)
     return [elem_retval for elem_retval in retval]
 
   def save (self, name, arg1):
